@@ -22,8 +22,8 @@ import click
 @click.option('-l', '--log_level', default="INFO", help='Log level')
 @click.option('--eigen/--no-eigen', default=False, help='Compute eigenvalues and vectors')
 @click.option('--strategy', type=int, default=0, help='Default strategy')
-@click.option('--fix-cache/no-fix-cache', default=True, help='Fix StarMomentMorph cache')
-@click.option('--fix-multi/no-fix-multi', default=True, help='Fix MultiPdf level 2')
+@click.option('--fix-cache/--no-fix-cache', default=True, help='Fix StarMomentMorph cache')
+@click.option('--fix-multi/--no-fix-multi', default=True, help='Fix MultiPdf level 2')
 @click.option('--offset/--no-offset', default=True, help='Offset likelihood')
 @click.option('--optimize/--no-optimize', default=True, help='Optimize constant terms')
 @click.option('--max_calls', type=int, default=-1, help='Maximum number of function calls')
@@ -123,4 +123,14 @@ def likelihood_scan(**kwargs):
     Tool for likelihood scan
     """
     from quickstats.components.likelihood import scan_nll
-    scan_nll(**kwargs)
\ No newline at end of file
+    scan_nll(**kwargs)
+
+
+
+@click.command(name='compile')
+def compile_macros():
+    """
+    Compile ROOT macros
+    """
+    from quickstats.utils.root_utils import compile_macro
+    compile_macro("RooTwoSidedCBShape")
\ No newline at end of file
