@@ -202,7 +202,11 @@ class ExtendedMinimizer(object):
         
         # Obtain Hessian matrix either from patched Minuit or after inversion
         # TMatrixDSym G = Minuit2::MnHesse::lastHessian();
-        self.Hessian_matrix = self.minimizer.lastMinuitFit().covarianceMatrix().Invert()
+        last_fit = self.minimizer.lastMinuitFit()
+        if last_fit:
+            self.Hessian_matrix = last_fit.covarianceMatrix().Invert()
+        else:
+            self.Hessian_matrix = None
         
         # Eigenvalue and eigenvector analysis
         if self.config['eigen']:
