@@ -12,6 +12,7 @@ import ROOT
 
 import quickstats
 from quickstats.components.numerics import is_integer
+from quickstats.utils.root_utils import load_macro
 
 class ExtendedModel(object):
     def __init__(self, fname:str, ws_name:str="combWS",
@@ -65,11 +66,11 @@ class ExtendedModel(object):
     def load_extension():
         try:
             if not hasattr(ROOT, 'RooTwoSidedCBShape'):
-                ROOT.gSystem.Load(os.path.join(quickstats.macro_path, 'macros', 'RooTwoSidedCBShape_cxx'))
+                result = load_macro('RooTwoSidedCBShape')
                 if hasattr(ROOT, 'RooTwoSidedCBShape'):
                     print('INFO: Loaded extension module "RooTwoSidedCBShape"')
-        except Exception:
-            print('WARNING: Failed to load extension module "RooTwoSidedCBShape"')
+        except Exception as e:
+            print(e)
     @staticmethod
     def modify_interp_codes(ws, interp_code, classes=None):
         if classes is None:
@@ -114,6 +115,7 @@ class ExtendedModel(object):
     
     @staticmethod
     def get_nuisance_parameter_names(fname:str, ws_name:str, model_config_name:str):
+        ExtendedModel.load_extension()
         if not os.path.exists(fname):
             raise FileNotFoundError('workspace file {} does not exist'.format(fname))
         file = ROOT.TFile(fname) 
@@ -556,17 +558,4 @@ class ExtendedModel(object):
         if as_str:
             return [data.GetName() for data in ws.allData()]                
         else:
-            return [data for data in ws.allData()]  
-                
-                
-                
-                
-                
-                
-                
-                
-                
-                
-                
-                
-                
\ No newline at end of file
+            return [data for data in ws.allData()]  
\ No newline at end of file
