@@ -474,7 +474,7 @@ class NuisanceParameterPull(object):
                   binned:bool=1, precision:float=0.001, eps:float=1.0, log_level:str='INFO', eigen:bool=False, 
                   strategy:int=0, fix_cache:bool=True, fix_multi:bool=True, offset:bool=True, optimize:bool=True,
                   parameter:str="", max_calls:int=-1, max_iters:int=-1, parallel:int=0, cache:bool=True, 
-                  exclud:str='', **kwargs):
+                  exclude:str='', **kwargs):
         
         start_time = time.time()
         
